@@ -101,6 +101,10 @@ class PyRunner:
     self._init_params['proc_file'] = value
     return self
   
+  @property
+  def context(self):
+    return self.engine.context
+  
   def reset_env(self):
     os.environ.clear()
     os.environ.update(self._environ)
@@ -373,29 +377,6 @@ class PyRunner:
         sys.exit(0)
       else:
         raise ValueError("Error during parsing of opts")
-    
-    # Export Command Line Vars to Environment
-    #for v in env_vars:
-    #  os.environ[v] = env_vars[v]
-    #
-    #self.source_config_file(config_file)
-    #
-    #if restart:
-    #  if not self.load_last_failed():
-    #    self.load_proc_list_file(proc_file)
-    #else:
-    #  self.load_proc_list_file(proc_file)
-    #
-    #if exec_proc_name:
-    #  self.exec_only([self.register.find_node(name=exec_proc_name).id])
-    #if exec_only_list:
-    #  self.exec_only(exec_only_list)
-    #if exec_disable_list:
-    #  self.exec_disable(exec_disable_list)
-    #if exec_from_id is not None:
-    #  self.exec_from(exec_from_id)
-    #if exec_to_id is not None:
-    #  self.exec_to(exec_to_id)
   
   def show_help(self):
     print("Required:")
